"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactDom = require("react-dom");

var _instance = _interopRequireDefault(require("./../Context/instance.js"));

var _CameraRecorder = _interopRequireDefault(require("./CameraRecorder.js"));

var _excluded = ["portal", "onHide", "onRecord", "maxDuration", "children"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Camera = (0, _react.forwardRef)(function (_ref, ref) {
  var portal = _ref.portal,
      onHide = _ref.onHide,
      onRecord = _ref.onRecord,
      maxDuration = _ref.maxDuration,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  // context
  var context = (0, _react.useContext)(_instance["default"]) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  };

  var _useState = (0, _react.useState)({}),
      successResult = _useState[0],
      setSuccessResult = _useState[1];

  var videoRef = (0, _react.useRef)(null);
  var startRef = (0, _react.useRef)(null);
  var stopRef = (0, _react.useRef)(null);
  var timeRef = (0, _react.useRef)(null);
  var timeTargetRef = (0, _react.useRef)(null);
  var successRef = (0, _react.useRef)(null);
  var errorRef = (0, _react.useRef)(null);
  var errorTargetRef = (0, _react.useRef)(null);
  (0, _react.useImperativeHandle)(ref, function () {
    return videoRef.current;
  });

  function openCamera() {
    _CameraRecorder["default"].init({
      maxDuration: maxDuration,
      timer: timeTargetRef.current,
      video: videoRef.current,
      onOpened: function onOpened(e, stream) {
        if (startRef.current) startRef.current.style.display = 'block'; // e.target.play();
      },
      onStop: function onStop(e) {
        if (stopRef.current) stopRef.current.style.display = 'none';
        if (timeRef.current) timeRef.current.style.display = 'none';
        if (successRef.current) successRef.current.style.display = 'block';
        setSuccessResult(e);
      },
      onError: function onError(e, err) {
        if (errorRef.current) errorRef.current.style.display = 'block';
        if (errorTargetRef.current) errorTargetRef.current.innerHTML = err.errMsg;
      }
    });
  }

  function start() {
    _CameraRecorder["default"].startRecord();

    startRef.current.style.display = 'none';
    stopRef.current.style.display = 'block';
    timeRef.current.style.display = 'block';
  }

  function stop(e) {
    _CameraRecorder["default"].stopRecord();
  }

  function closeCamera(e) {
    _CameraRecorder["default"].stopRecord(null); // 关闭不走停止onStop回调


    if (onHide) onHide(e);
  }

  function success() {
    onRecord(successResult);
  }

  (0, _react.useEffect)(function () {
    openCamera();
  }, []);
  return (0, _reactDom.createPortal)( /*#__PURE__*/_react["default"].createElement("div", _extends({
    ref: ref
  }, others, {
    className: "camera" + (others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/_react["default"].createElement("video", {
    ref: videoRef,
    width: "100%",
    height: "100%",
    autoPlay: "",
    playsInline: true,
    muted: true
  }), /*#__PURE__*/_react["default"].createElement("div", {
    ref: startRef,
    className: "camera-recorder-start",
    onClick: start
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "camera-recorder-start-round"
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "camera-recorder-start-dot"
  }))), /*#__PURE__*/_react["default"].createElement("div", {
    ref: stopRef,
    className: "camera-recorder-stop",
    onClick: stop
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "camera-recorder-stop-dot"
  })), /*#__PURE__*/_react["default"].createElement("div", {
    ref: successRef,
    className: "camera-success",
    onClick: success
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "camera-success-icon"
  })), /*#__PURE__*/_react["default"].createElement("div", {
    ref: timeRef,
    className: "camera-recorder-timer"
  }, /*#__PURE__*/_react["default"].createElement("span", {
    className: "camera-recorder-timer-dot"
  }), /*#__PURE__*/_react["default"].createElement("span", {
    ref: timeTargetRef,
    className: "camera-recorder-timer-label"
  }, "00:00")), /*#__PURE__*/_react["default"].createElement("div", {
    ref: errorRef,
    className: "camera-recorder-error"
  }, /*#__PURE__*/_react["default"].createElement("span", {
    ref: errorTargetRef,
    className: "camera-recorder-error-label"
  })), /*#__PURE__*/_react["default"].createElement("div", {
    className: "camera-close",
    onClick: closeCamera
  }), children), portal || context.portal || document.getElementById('root') || document.body);
});
var _default = Camera;
exports["default"] = _default;
module.exports = exports.default;